C XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
C
C SUBROUTINE AND TEST PROGRAM FOR MAP PROJECT
C
C CALCULATES THE CLASSICAL ACTIVATION ENERGY BARRIER TO NUCLEATION AT
C A PLANAR GRAIN BOUNDARY.
C
C EASILY MODIFIED TO CALCULATE THE ACTIVATION ENERGY BARRIER TO NUCLEATION 
C AT A PLANAR SUBSTRATE.
C
C BY        S J JONES & H K D H BHADESHIA
C           DEPT OF MATERIALS SCIENCE & METALLURGY
C           UNIVERSITY OF CAMBRIDGE
C           UNITED KINGDOM
C
C XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

        SUBROUTINE MAP_STEEL_GB_POTENCY(GBGMAX1VOL,GMAX1VOL,UFAFENERGY,
     &  FAFENERGY,AGBENERGY,GBAEB,AEBHOMOG,GBFRACHOMAEB)

        IMPLICIT NONE
        DOUBLE PRECISION GBGMAX1VOL, GMAX1VOL, UFAFENERGY, FAFENERGY
        DOUBLE PRECISION AGBENERGY, GBAEB, AEBHOMOG, GBFRACHOMAEB
        DOUBLE PRECISION PI, GBRC, GBBETA, GBFUNCBETA, TESTY, GBSIGMA
        DOUBLE PRECISION GBFUNCSIGMA, GBVSEG, GBVC3, GBASEG, GBAC2
        DOUBLE PRECISION GBAC4, GBAF, NUCSTRAIN1VOL
C
        PARAMETER (PI=3.141592654)

C CLASSICAL MODEL FOR NUCLEATION AT A PLANAR GRAIN BOUNDARY.

C MODEL ASSUMES THAT FERRITE NUCLEUS GROWS INTO BOTH ADJACENT AUSTENITE
C GRAINS. HOWEVER A LOW-ENERGY FACET ONLY FORMS IN ONE GRAIN.

C THUS EASILY MODIFIED TO CALCULATE THE ACTIVATION ENERGY BARRIER TO 
C NUCLEATION AT A PLANAR SUBSTRATE.

C ASSUMES :-

C (1) DIFFERENT INTERFACIAL ENERGY TERMS (IE. WETTING NOT = 90 DEG.)
C (2) FACETTED GROWTH.
C (3) DEPLETION/ENRICHMENT IN LOCAL ALLOYING ELEMENTS LOCAL TO BOUNDARY.

C GBRC=RADIUS OF CRITICAL NUCLEUS 'HOMOGENEOUS' NUCLEI LOCAL TO THE BOUNDARY:

       GBRC=(-2.0*UFAFENERGY)/GBGMAX1VOL

C HOMOGENEOUS ACTIVATION ENERGY BARRIER REMOTE FROM THE BOUNDARY:

       AEBHOMOG=(16.0*PI/3.0)*(UFAFENERGY**3)/(GMAX1VOL**2.0)
        
       IF (FAFENERGY.GT.UFAFENERGY) THEN
         WRITE(*,*) "ERROR - INTERFACIAL ENERGY (1) !"
         PAUSE
       ENDIF

C GBBETA=ANGLE BETWEEN (RAD) CHORD WHICH 'SEPARATES' AUSTENITE AND THE FACETED
C FERRITE AND THE TANGENT TO THE UNFACETED FERRITE AT THE DOUBLE POINT.

        GBBETA=ACOS(FAFENERGY/UFAFENERGY)
        GBFUNCBETA=2.0-(3.0*COS(GBBETA))+((COS(GBBETA))**3.0)

C GBSIGMA=ANGLE (RAD) WHICH SEPARATES 'ORIGINAL' PAG BOUNDARY AND FERRITE
C IE. THE 'WETTING' ANGLE.

         TESTY=AGBENERGY/(2.0*UFAFENERGY)

         IF ((TESTY.GT.1.0).OR.(TESTY.LT.0.0)) THEN
          WRITE(*,*) "ERROR - INTERFACIAL ENERGY (2) !"
          PAUSE
         ENDIF

        GBSIGMA=ACOS(TESTY)
        GBFUNCSIGMA=2.0-(3.0*COS(GBSIGMA))+((COS(GBSIGMA))**3.0)
    
C VOLUME TERMS:

C GBVSEG=VOLUME OF 'IDENTICAL' SEGEMENTS EITHER SIDE OF PAG BOUNDARY.
C GBVC3=SPHERICAL SEGMENT LOST DUE FORMATION OF FACET.
        GBVSEG=(1.0*PI/3.0)*(GBRC**3.0)*GBFUNCSIGMA
        GBVC3=(1.0*PI/3.0)*(GBRC**3.0)*GBFUNCBETA
     
C AREA TERMS:

C GBASEG=CURVED SURFACE AREA OF 'IDENTICAL' SEGEMENTS EITHER SIDE
C OF PAG BOUNDARY.
C GBAC2=AREA AUSTENITE/PAG INTERFACE DESTROYED OR FERRITE/AUSTENITE 
C (PAG) INTERFACE CREATED.
C GBAC4=AREA OF NUCLEUS LOST DUE TO FACET FORMATION.
C GBAF=AREA OF NUCLEUS CREATED DUE TO FACET FORMATION.

        GBASEG=2.0*PI*(GBRC**2.0)*(1.0-COS(GBSIGMA))
        GBAC2=1.0*PI*(GBRC**2.0)*(1.0-(COS(GBSIGMA)**2.0))
        GBAC4=2.0*PI*(GBRC**2.0)*(1.0-COS(GBBETA))
        GBAF=1.0*PI*(GBRC**2.0)*(1.0-((COS(GBBETA))**2.0))

          IF (GBSIGMA.GT.GBBETA) THEN

C THE SEGMENT LOST DUE TO FACETTING IS SMALLER THAN THE FERRITE NUCLEUS SEGMENT
C ON THAT SIDE OF THE BOUNDARY (MODEL D JOHNSON ET AL. MET. TRANS. A - APRIL 
C 1975) IE. NUCLEUS VOLUME ON BOTH SIDES OF THE PAG BOUNDARY.

           GBAEB=(((2.0*GBVSEG)-GBVC3)*GBGMAX1VOL)
     &    +(NUCSTRAIN1VOL*((2.0*GBVSEG)-GBVC3))
     &    +(((2.0*GBASEG)-GBAC4)*UFAFENERGY)
     &    +(GBAF*FAFENERGY)
     &    -(GBAC2*AGBENERGY)

          ELSEIF (GBSIGMA.LE.GBBETA) THEN

C SEGMENT LOST DUE TO FACET IS LARGER OR EQUAL TO THE FERRITE NUCLEUS SEGMENT
C (MODEL D REDUCES TO TYPE E JOHNSON ET AL. MET. TRANS. A - APRIL 1975)
C IE. MAXIMUM POSSIBLE REDUCTION IN ENERGY BARRIER - ENTIRE HIGH ENERGY PAG 
C BOUNDARY THAT IS DESTROYED IS REPLACED WITH A LOW ENERGY FACET.

           GBAEB=(GBVSEG*GBGMAX1VOL)
     &    +(NUCSTRAIN1VOL*GBVSEG)
     &    +(GBASEG*UFAFENERGY)
     &    +(GBAC2*FAFENERGY)
     &    -(GBAC2*AGBENERGY)

          ENDIF

C COMPARE WITH HOMOGENEOUS ACTIVATION ENERGY BARRIER (EFFECTIVE 'SHAPE' FACTOR):

         GBFRACHOMAEB=GBAEB/AEBHOMOG

         RETURN

         END

C XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
